pub struct DeterministicHasher { /* private fields */ }Expand description
A deterministic hasher with a seeded state.
Uses rapidhash which produces identical results regardless of target CPU features, unlike ahash which uses different algorithms with/without AES-NI.
Implementations