StreamingQueryEngine

Struct StreamingQueryEngine 

pub struct StreamingQueryEngine<'a, const K: usize>
where Kmer<K>: KmerBits,
{ /* private fields */ }
Streaming query engine integrated with Dictionary

This provides the full streaming query functionality by connecting to a Dictionary instance for actual k-mer lookups.

Implementations

Source

impl<'a, const K: usize> StreamingQueryEngine<'a, K>
where Kmer<K>: KmerBits,

pub fn new(dict: &'a Dictionary) -> Self

Create a new streaming query engine for a dictionary

pub fn reset(&mut self)

Reset the query state

pub fn lookup(&mut self, kmer_bytes: &[u8]) -> LookupResult

Perform a streaming lookup

pub fn num_searches(&self) -> u64

Get the number of full searches performed

pub fn num_extensions(&self) -> u64

Get the number of extensions (no search needed)

pub fn stats(&self) -> StreamingQueryStats

Get statistics