pub struct MinimizerIterator { /* private fields */ }Expand description
Iterator that extracts minimizers from k-mers using the “re-scan” method
This is an efficient minimizer extraction algorithm that:
- Rescans the window when the minimum falls out
- Performs single comparisons for sliding updates
- Tracks the position of the minimum within the k-mer window
Example
use sshash_lib::kmer::Kmer;
use sshash_lib::minimizer::MinimizerIterator;
// Create iterator for k-mer size 31, minimizer size 13
let mut iter = MinimizerIterator::new(31, 13, 0);
// Process a k-mer and extract minimizer
let kmer: Kmer<31> = Kmer::from_str("ACGTACGTACGTACGTACGTACGTACGTACG").unwrap();
let mini = iter.next(kmer);
println!("Minimizer at position {} in k-mer, global position {}",
mini.pos_in_kmer, mini.position);Implementations
Sourceimpl MinimizerIterator
impl MinimizerIterator
Sourcepub fn with_seed(k: usize, m: usize, seed: u64) -> Self
pub fn with_seed(k: usize, m: usize, seed: u64) -> Self
Create a new minimizer iterator with a seeded hasher
Arguments
k- k-mer size (must be >= m)m- minimizer size (must be <= k)seed- seed for the hash function (for deterministic results)
Sourcepub fn new(k: usize, m: usize, _position: u64) -> Self
pub fn new(k: usize, m: usize, _position: u64) -> Self
Create a new minimizer iterator (defaults to seed=1)
Arguments
k- k-mer size (must be >= m)m- minimizer size (must be <= k)_position- (deprecated parameter for API compatibility)
Sourcepub fn set_position(&mut self, position: u64)
pub fn set_position(&mut self, position: u64)
Set a new starting position