pub struct StreamingQueryEngine<'a, const K: usize>{ /* private fields */ }Expand description
Streaming query engine integrated with Dictionary
This provides the full streaming query functionality by connecting to a Dictionary instance for actual k-mer lookups.
Implementations
Sourceimpl<'a, const K: usize> StreamingQueryEngine<'a, K>
impl<'a, const K: usize> StreamingQueryEngine<'a, K>
Sourcepub fn new(dict: &'a Dictionary) -> Self
pub fn new(dict: &'a Dictionary) -> Self
Create a new streaming query engine for a dictionary
Sourcepub fn lookup(&mut self, kmer_bytes: &[u8]) -> LookupResult
pub fn lookup(&mut self, kmer_bytes: &[u8]) -> LookupResult
Perform a streaming lookup
Sourcepub fn num_searches(&self) -> u64
pub fn num_searches(&self) -> u64
Get the number of full searches performed
Sourcepub fn num_extensions(&self) -> u64
pub fn num_extensions(&self) -> u64
Get the number of extensions (no search needed)
Sourcepub fn stats(&self) -> StreamingQueryStats
pub fn stats(&self) -> StreamingQueryStats
Get statistics